/*

DESCRIPTION:	shared include file containing constants representing common
		object sizes, value limits, and characters.

COPYRIGHT:	(c) 2023, Brian Cornell, all rights reserved.

DEPENDENCIES:	none.

VERSION:	n/a.

MODIFICATION HISTORY:

    12 Jan 23, BWC, created file.


*/


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Convention:  S_<TYPE>_<INFO>. TYPE:
 *  + AL=ALias
 *  + AR=ARray address
 *  + BL=boolean value
 *  + BP=bit position within a data object
 *  + CC=Calibration Constant
 *  + CD=command data
 *  + CH=character
 *  + DC=Duty Cycle
 *  + DF=Default value for a configurable parameter
 *  + EN=ENable bit
 *  + IN=INitializing value
 *  + LM=LiMiting operational value
 *  + OF=OFfset in an array, list, etc.
 *  + MK=bit MasK
 *  + MP=Peripheral port bit MaPping
 *  + QY=quantity (count) of something
 *  + RT=RaTio or scaling factor
 *  + SL=SeLection value
 *  + SZ=size of an object or data type
 *  + TM=TiMing
 *  + VL=VoLtage
 * 
 * INFO is user defined and should be descriptive.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define S_SZ_BYTE           8               //Number of bits in a byte
#define S_MK_U16_L          0x00FF          //Access low byte of 16-bit unsigned
#define S_MK_U16_H          0xFF00          //Access hi byte of 16-bit unsigned
#define S_RT_PERCENT        100             //Calculate % of a dividend value
#define S_LM_U8             255             //Maximum value for uint8_t
#define S_LM_U16            65535           //Maximum value for uint16_t
#define S_QY_MS_S           1000            //Number of mS in one second
#define S_QY_SECHOUR        3600            //Number of seconds in an hour
#define S_CH_SPACE          ' '             //White space
#define S_CH_DECIMAL        '.'             //Decimal point
#define S_CH_COMMA          ','             //Comma
#define S_CH_NEWLINE        '\n'            //New line
#define S_CH_NULL           0x00            //NULL byte (string terminator)



//End of file
