/*

DESCRIPTION:  include file for usart-v3.c. DO NOT EDIT THIS FILE! User 
              configuration is done in usartc.h.

SYNTAX:  n/a

KNOWN BUGS:  n/a.

COPYRIGHT:  (c) 2017-2023, Brian Cornell, all rights reserved.

DEPENDENCIES:  none

VERSION:  3.0, release

MODIFICATION HISTORY:

    18 Jan 23, BWC, upated for clarity that this is a system include file that
    should not be edited. Defined _USART constant for source file inclusion
    management

    7 Mar 22, BWC, created v3 that breaks out user configuration constants for
    easier portability & integration across projects.

    3 Aug 20, BWC, Relabeled "//Keyboard codes" section to "//Character codes"
    and added definition for NULL character byte.

    15 Oct 19, BWC, added usartWrite function declaration.

    25 Sep 19, BWC, updated pins to use for PIC16F1769 and validated baud rate
    configuration for 115.2Kbps.

    4 Apr 19, BWC, removed _XTAL_FREQ definition. 
    Defined buffer termination character USARTKEYNL for new line

    19 Apr 17, BWC, updated to stay in sync with model 2.0 code that includes 
                    optional flow control.

    5 apr 17, BWC, released v1.0.

    7 Dec 16, BWC, created file.

*/


//This file has been 'included'.
#define _USART

//USART module status codes
#define USARTSTSRXRCV   0x01            //Receive in progress (implies enabled)
#define USARTSTSRXRDY   0x02            //Buffer has NULL terminated line ready for read (implies disabled)
#define USARTSTSRXDIS   0x04            //Buffer is empty and Rx is disabled
#define USARTSTSRXENA   0x08            //Buffer is empty and Rx is enabled
#define USARTSTSRXINT   0x80            //Not initialized
#define USARTSTSTXRDY   0x01            //Tx ready to send
#define USARTSTSTXCTS   0x02            //Tx not ready - CTS set
#define USARTSTSTXBSY   0x04            //Tx not ready - buffer full
#define USARTSTSTXINT   0x80            //Not initialized

//Character codes
#define USARTKEYBS      0x08            //Backspace
#define USARTKEYCR      0x0D            //Carriage return
#define USARTKEYNL      0x0A            //New line
#define USARTCHRNULL    0x00            //String terminator

#define USARTUI16BUF    5               //Size of ASCII version of uint16_t
#define USARTUI24BUF    8               //Size of ASCII version of uint24_t
#define USARTWRSZBUF    USARTUI24BUF    //Buffer size for ASCII output of usar_wr functions

//Macro for echoing received byte during data entry
#define USARTECHO()     if (TXIF && RxEcho) TX1REG = RxByte

//Macro to 'hide' putch and allow for uniform naming of user write (wr) functions
#define usart_wr_chr(c) putch(c)


//Function declarations.  See source file for explanation of each function.
void usartISR(void);
void usartSetRx(unsigned char);
unsigned char usartStatRx(void);
void usartSetEcho(unsigned char);
unsigned char usartStatTx(void);
unsigned char * usartGetRx(void);
unsigned char usartTxBkgd(unsigned char *, unsigned char);
void putch(char);
uint8_t usartWrite(void *, uint8_t);
void usart_wr_ui16(uint16_t);
void usart_wr_ui24(uint24_t);
void usart_wr_str(char *);
unsigned char usartGetSz(void);



//End of file
